document.addEventListener('DOMContentLoaded', () => {
  const pythonCode = document.getElementById('pythonCode');
  const calculateBtn = document.getElementById('calculateBtn');
  const result = document.getElementById('result');
  const historyList = document.getElementById('historyList');
  
  let calculationHistory = [];
  
  const updateResult = async (code) => {
    try {
      const response = await fetch('/api/calculate', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ code })
      });
      
      const data = await response.json();
      
      if (data.error) {
        result.innerHTML = `<span style="color: red">Error: ${data.error}</span>`;
      } else {
        result.textContent = data.result;
        addToHistory(code, data.result);
      }
    } catch (err) {
      result.innerHTML = `<span style="color: red">Server Error: ${err.message}</span>`;
    }
  };
  
  const addToHistory = (code, result) => {
    calculationHistory.unshift({ code, result, timestamp: new Date() });
    if (calculationHistory.length > 5) calculationHistory.pop();
    updateHistoryDisplay();
  };
  
  const updateHistoryDisplay = () => {
    historyList.innerHTML = calculationHistory
      .map(item => `
        <li>
          <code>${item.code}</code>
          <br>
          = ${item.result}
          <small>(${item.timestamp.toLocaleTimeString()})</small>
        </li>
      `)
      .join('');
  };
  
  calculateBtn.addEventListener('click', () => {
    const code = pythonCode.value.trim();
    if (code) {
      updateResult(code);
    }
  });
  
  pythonCode.addEventListener('keydown', (e) => {
    if (e.ctrlKey && e.key === 'Enter') {
      calculateBtn.click();
    }
  });
});
